// packages/html-rewriter/src/plugin.ts
import { Plugin } from "@miniflare/shared";

// packages/html-rewriter/src/rewriter.ts
import { ReadableStream } from "stream/web";
import { TextEncoder } from "util";
import { Response } from "@miniflare/core";
var encoder = new TextEncoder();
function transformToArray(chunk) {
  if (chunk instanceof Uint8Array) {
    return chunk;
  } else if (ArrayBuffer.isView(chunk)) {
    return new Uint8Array(chunk.buffer, chunk.byteOffset, chunk.byteLength);
  } else if (chunk instanceof ArrayBuffer) {
    return new Uint8Array(chunk);
  } else if (Array.isArray(chunk) && chunk.every((value) => typeof value === "number")) {
    return new Uint8Array(chunk);
  } else if (typeof chunk === "number") {
    return new Uint8Array([chunk]);
  } else if (chunk === null || chunk === void 0) {
    throw new TypeError("Chunk must be defined");
  } else {
    return encoder.encode(String(chunk));
  }
}
var HTMLRewriter = class {
  #elementHandlers = [];
  #documentHandlers = [];
  on(selector, handlers) {
    this.#elementHandlers.push([selector, handlers]);
    return this;
  }
  onDocument(handlers) {
    this.#documentHandlers.push(handlers);
    return this;
  }
  transform(response) {
    const transformedStream = new ReadableStream({
      type: "bytes",
      start: async (controller) => {
        const { HTMLRewriter: BaseHTMLRewriter } = await import("html-rewriter-wasm");
        const rewriter = new BaseHTMLRewriter((output) => {
          if (output.length !== 0)
            controller.enqueue(output);
        });
        for (const [selector, handlers] of this.#elementHandlers) {
          rewriter.on(selector, handlers);
        }
        for (const handlers of this.#documentHandlers) {
          rewriter.onDocument(handlers);
        }
        try {
          if (response.body) {
            for await (const chunk of response.body) {
              await rewriter.write(transformToArray(chunk));
            }
          }
          await rewriter.end();
        } catch (e) {
          controller.error(e);
        } finally {
          rewriter.free();
          controller.close();
        }
      }
    });
    return new Response(transformedStream, response);
  }
};

// packages/html-rewriter/src/plugin.ts
var HTMLRewriterPlugin = class extends Plugin {
  constructor(log, compat) {
    super(log, compat);
  }
  setup() {
    return { globals: { HTMLRewriter } };
  }
};
export {
  HTMLRewriter,
  HTMLRewriterPlugin
};
//# sourceMappingURL=index.js.map
